from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class BookletOptions(SpireObject):
    """
    The booklet options.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the BookletOptions class.
        """
        GetDllLibPdf().BookletOptions_CreateBookletOptions.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().BookletOptions_CreateBookletOptions)
        super(BookletOptions, self).__init__(intPtr)

    @property
    def BookletBinding(self) -> 'PdfBookletBindingMode':
        """
        Gets or sets the booklet binding mode. The default value is Left.
        """
        GetDllLibPdf().BookletOptions_get_BookletBinding.argtypes = [c_void_p]
        GetDllLibPdf().BookletOptions_get_BookletBinding.restype = c_int
        ret = CallCFunction(GetDllLibPdf().BookletOptions_get_BookletBinding,self.Ptr)
        objwrapped = PdfBookletBindingMode(ret)
        return objwrapped

    @BookletBinding.setter
    def BookletBinding(self, value: 'PdfBookletBindingMode'):
        """
        Sets the booklet binding mode.
        """
        GetDllLibPdf().BookletOptions_set_BookletBinding.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().BookletOptions_set_BookletBinding,self.Ptr, value.value)
