from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAnnotationActions(SpireObject):
    """
    Represents additional actions of the annotations.
    """

    @property
    def MouseEnter(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the mouse enters the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_get_MouseEnter.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_MouseEnter.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_MouseEnter,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @MouseEnter.setter
    def MouseEnter(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the mouse enters the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_set_MouseEnter.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_MouseEnter,self.Ptr, value.Ptr)

    @property
    def MouseLeave(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the mouse leaves the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_get_MouseLeave.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_MouseLeave.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_MouseLeave,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @MouseLeave.setter
    def MouseLeave(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the mouse leaves the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_set_MouseLeave.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_MouseLeave,self.Ptr, value.Ptr)

    @property
    def MouseDown(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is pressed inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_get_MouseDown.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_MouseDown.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_MouseDown,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @MouseDown.setter
    def MouseDown(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the mouse button is pressed inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_set_MouseDown.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_MouseDown,self.Ptr, value.Ptr)

    @property
    def MouseUp(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is released inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_get_MouseUp.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_MouseUp.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_MouseUp,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @MouseUp.setter
    def MouseUp(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the mouse button is released inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_set_MouseUp.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_MouseUp,self.Ptr, value.Ptr)

    @property
    def GotFocus(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the annotation receives the input focus.
        """
        GetDllLibPdf().PdfAnnotationActions_get_GotFocus.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_GotFocus.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_GotFocus,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @GotFocus.setter
    def GotFocus(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the annotation receives the input focus.
        """
        GetDllLibPdf().PdfAnnotationActions_set_GotFocus.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_GotFocus,self.Ptr, value.Ptr)

    @property
    def LostFocus(self) -> 'PdfAction':
        """
        Gets or sets the action to be performed when the annotation loses the input focus.
        """
        GetDllLibPdf().PdfAnnotationActions_get_LostFocus.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_LostFocus.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_LostFocus,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @LostFocus.setter
    def LostFocus(self, value: 'PdfAction'):
        """
        Sets the action to be performed when the annotation loses the input focus.
        """
        GetDllLibPdf().PdfAnnotationActions_set_LostFocus.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_LostFocus,self.Ptr, value.Ptr)

    @property
    def Caculate(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed when the annotation is calculated.
        """
        GetDllLibPdf().PdfAnnotationActions_get_Caculate.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_Caculate.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_Caculate,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @Caculate.setter
    def Caculate(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed when the annotation is calculated.
        """
        GetDllLibPdf().PdfAnnotationActions_set_Caculate.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_Caculate,self.Ptr, value.Ptr)

    @property
    def Validate(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed when the annotation is validated.
        """
        GetDllLibPdf().PdfAnnotationActions_get_Validate.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_Validate.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_Validate,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @Validate.setter
    def Validate(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed when the annotation is validated.
        """
        GetDllLibPdf().PdfAnnotationActions_set_Validate.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_Validate,self.Ptr, value.Ptr)

    @property
    def KeyPressed(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed when a key is pressed inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_get_KeyPressed.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_KeyPressed.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_KeyPressed,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @KeyPressed.setter
    def KeyPressed(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed when a key is pressed inside the annotations active area.
        """
        GetDllLibPdf().PdfAnnotationActions_set_KeyPressed.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_KeyPressed,self.Ptr, value.Ptr)

    @property
    def Format(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed when the annotation is formatted.
        """
        GetDllLibPdf().PdfAnnotationActions_get_Format.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationActions_get_Format.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationActions_get_Format,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @Format.setter
    def Format(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed when the annotation is formatted.
        """
        GetDllLibPdf().PdfAnnotationActions_set_Format.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationActions_set_Format,self.Ptr, value.Ptr)