from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAppearanceState(SpireObject):
    """
    Represents the states of an annotation's appearance.
    """

    @property
    def On(self) -> 'PdfTemplate':
        """
        Gets or sets the active state template.
        :return: The active state template.
        """
        GetDllLibPdf().PdfAppearanceState_get_On.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearanceState_get_On.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearanceState_get_On,self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @On.setter
    def On(self, value: 'PdfTemplate'):
        """
        Sets the active state template.
        :param value: The active state template.
        """
        GetDllLibPdf().PdfAppearanceState_set_On.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAppearanceState_set_On,self.Ptr, value.Ptr)

    @property
    def Off(self) -> 'PdfTemplate':
        """
        Gets or sets the inactive state.
        :return: The inactive state template.
        """
        GetDllLibPdf().PdfAppearanceState_get_Off.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearanceState_get_Off.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearanceState_get_Off,self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @Off.setter
    def Off(self, value: 'PdfTemplate'):
        """
        Sets the inactive state template.
        :param value: The inactive state template.
        """
        GetDllLibPdf().PdfAppearanceState_set_Off.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAppearanceState_set_Off,self.Ptr, value.Ptr)

    @property
    def OnMappingName(self) -> str:
        """
        Gets or sets the mapping name of the active state.
        :return: The mapping name of the active state.
        """
        GetDllLibPdf().PdfAppearanceState_get_OnMappingName.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearanceState_get_OnMappingName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfAppearanceState_get_OnMappingName,self.Ptr))
        return ret

    @OnMappingName.setter
    def OnMappingName(self, value: str):
        """
        Sets the mapping name of the active state.
        :param value: The mapping name of the active state.
        """
        GetDllLibPdf().PdfAppearanceState_set_OnMappingName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfAppearanceState_set_OnMappingName,self.Ptr, value)

    @property
    def OffMappingName(self) -> str:
        """
        Gets or sets the mapping name of the inactive state.
        :return: The mapping name of the inactive state.
        """
        GetDllLibPdf().PdfAppearanceState_get_OffMappingName.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearanceState_get_OffMappingName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfAppearanceState_get_OffMappingName,self.Ptr))
        return ret

    @OffMappingName.setter
    def OffMappingName(self, value: str):
        """
        Sets the mapping name of the inactive state.
        :param value: The mapping name of the inactive state.
        """
        GetDllLibPdf().PdfAppearanceState_set_OffMappingName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfAppearanceState_set_OffMappingName,self.Ptr, value)