from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfButtonIconLayout(SpireObject):
    """
    Represents the button icon layout options.
    """

    @property
    def ScaleReason(self) -> 'PdfButtonIconScaleReason':
        """
        Gets or sets the circumstances under which the icon shall be scaled inside the annotation rectangle.
        """
        GetDllLibPdf().PdfButtonIconLayout_get_ScaleReason.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonIconLayout_get_ScaleReason.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfButtonIconLayout_get_ScaleReason,self.Ptr)
        objwrapped = PdfButtonIconScaleReason(ret)
        return objwrapped

    @ScaleReason.setter
    def ScaleReason(self, value: 'PdfButtonIconScaleReason'):
        """
        Sets the circumstances under which the icon shall be scaled inside the annotation rectangle.
        """
        GetDllLibPdf().PdfButtonIconLayout_set_ScaleReason.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfButtonIconLayout_set_ScaleReason,self.Ptr, value.value)

    @property
    def Spaces(self) -> List[float]:
        """
        Gets or sets an array of two numbers between 0.0 and 1.0 indicating the fraction of leftover space to allocate at the left and bottom of the icon.
        """
        GetDllLibPdf().PdfButtonIconLayout_get_Spaces.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonIconLayout_get_Spaces.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfButtonIconLayout_get_Spaces,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @Spaces.setter
    def Spaces(self, value: List[float]):
        """
        Sets an array of two numbers between 0.0 and 1.0 indicating the fraction of leftover space to allocate at the left and bottom of the icon.
        """
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfButtonIconLayout_set_Spaces.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfButtonIconLayout_set_Spaces,self.Ptr, vArray, vCount)

    @property
    def IsFitBounds(self) -> bool:
        """
        If true, indicates that the button appearance should be scaled to fit fully within the bounds of the annotation without taking into consideration the line width of the border.
        """
        GetDllLibPdf().PdfButtonIconLayout_get_IsFitBounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonIconLayout_get_IsFitBounds.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfButtonIconLayout_get_IsFitBounds,self.Ptr)
        return ret

    @IsFitBounds.setter
    def IsFitBounds(self, value: bool):
        """
        Sets whether the button appearance should be scaled to fit fully within the bounds of the annotation without taking into consideration the line width of the border.
        """
        GetDllLibPdf().PdfButtonIconLayout_set_IsFitBounds.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfButtonIconLayout_set_IsFitBounds,self.Ptr, value)

    @property
    def ScaleMode(self) -> 'PdfButtonIconScaleMode':
        """
        Gets or sets the type of scaling to use.
        """
        GetDllLibPdf().PdfButtonIconLayout_get_ScaleMode.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonIconLayout_get_ScaleMode.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfButtonIconLayout_get_ScaleMode,self.Ptr)
        objwrapped = PdfButtonIconScaleMode(ret)
        return objwrapped

    @ScaleMode.setter
    def ScaleMode(self, value: 'PdfButtonIconScaleMode'):
        """
        Sets the type of scaling to use.
        """
        GetDllLibPdf().PdfButtonIconLayout_set_ScaleMode.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfButtonIconLayout_set_ScaleMode,self.Ptr, value.value)