from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCellStyle(SpireObject):
    """
    Represents information about cell style.
    """
    @dispatch
    def __init__(self):
        GetDllLibPdf().PdfCellStyle_CreatePdfCellStyle.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_CreatePdfCellStyle)
        super(PdfCellStyle, self).__init__(intPtr)
    
    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush, pen: PdfPen):
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        ptrPen: c_void_p = pen.Ptr
        GetDllLibPdf().PdfCellStyle_CreatePdfCellStyleFFB.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfCellStyle_CreatePdfCellStyleFFB.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_CreatePdfCellStyleFFB,ptrFont, ptrBrush, ptrPen)
        super(PdfCellStyle, self).__init__(intPtr)
    
    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the font.
        """
        GetDllLibPdf().PdfCellStyle_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_Font.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_Font,self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret
    
    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        GetDllLibPdf().PdfCellStyle_set_Font.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_Font,self.Ptr, value.Ptr)
    
    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the string format of the cell text.
        """
        GetDllLibPdf().PdfCellStyle_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_StringFormat.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_StringFormat,self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret
    
    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        GetDllLibPdf().PdfCellStyle_set_StringFormat.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_StringFormat,self.Ptr, value.Ptr)
    
    @property
    def TextPen(self) -> 'PdfPen':
        """
        Gets or sets the font which will be used to draw text outlines.
        It should be null for default text representation.
        """
        GetDllLibPdf().PdfCellStyle_get_TextPen.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_TextPen.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_TextPen,self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret
    
    @TextPen.setter
    def TextPen(self, value: 'PdfPen'):
        GetDllLibPdf().PdfCellStyle_set_TextPen.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_TextPen,self.Ptr, value.Ptr)
    
    @property
    def TextBrush(self) -> 'PdfBrush':
        """
        Gets or sets the brush which will be used to draw font.
        This brush will be used to fill glyphs interior, which is the default.
        """
        GetDllLibPdf().PdfCellStyle_get_TextBrush.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_TextBrush.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_TextBrush,self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret
    
    @TextBrush.setter
    def TextBrush(self, value: 'PdfBrush'):
        GetDllLibPdf().PdfCellStyle_set_TextBrush.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_TextBrush,self.Ptr, value.Ptr)
    
    @property
    def BorderPen(self) -> 'PdfPen':
        """
        Gets or sets the pen with which the border will be drawn.
        """
        GetDllLibPdf().PdfCellStyle_get_BorderPen.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_BorderPen.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_BorderPen,self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret
    
    @BorderPen.setter
    def BorderPen(self, value: 'PdfPen'):
        GetDllLibPdf().PdfCellStyle_set_BorderPen.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_BorderPen,self.Ptr, value.Ptr)
    
    @property
    def BackgroundBrush(self) -> 'PdfBrush':
        """
        Gets or sets the brush with which the background will be drawn.
        It's null by default.
        """
        GetDllLibPdf().PdfCellStyle_get_BackgroundBrush.argtypes = [c_void_p]
        GetDllLibPdf().PdfCellStyle_get_BackgroundBrush.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCellStyle_get_BackgroundBrush,self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret
    
    @BackgroundBrush.setter
    def BackgroundBrush(self, value: 'PdfBrush'):
        GetDllLibPdf().PdfCellStyle_set_BackgroundBrush.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfCellStyle_set_BackgroundBrush,self.Ptr, value.Ptr)
