from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCheckBoxField(PdfCheckFieldBase):
    @dispatch
    def __init__(self, page: PdfPageBase, name: str):
        """
        Initializes a new instance of the PdfCheckBoxField class.

        Args:
            page (PdfPageBase): The PDF page.
            name (str): The name of the check box field.
        """
        ptrPage: c_void_p = page.Ptr
        GetDllLibPdf().PdfCheckBoxField_CreatePdfCheckBoxFieldPN.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfCheckBoxField_CreatePdfCheckBoxFieldPN.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCheckBoxField_CreatePdfCheckBoxFieldPN,ptrPage, name)
        super(PdfCheckBoxField, self).__init__(intPtr)

    @property
    def Checked(self) -> bool:
        """
        Gets or sets a value indicating whether this check box field is checked.

        Returns:
            bool: True if checked; otherwise, False.
        """
        GetDllLibPdf().PdfCheckBoxField_get_Checked.argtypes = [c_void_p]
        GetDllLibPdf().PdfCheckBoxField_get_Checked.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfCheckBoxField_get_Checked,self.Ptr)
        return ret

    @Checked.setter
    def Checked(self, value: bool):
        """
        Sets a value indicating whether this check box field is checked.

        Args:
            value (bool): True if checked; otherwise, False.
        """
        GetDllLibPdf().PdfCheckBoxField_set_Checked.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfCheckBoxField_set_Checked,self.Ptr, value)