from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCode128ABarcode(PdfUnidimensionalBarcode):
    """
    Represents a Code128A barcode.

    Only the following symbols are allowed in a Code 128 A barcode: NUL (\x00) SOH (\x01) STX (\x02) ETX (\x03) EOT (\x04) ENQ (\x05) ACK (\x06) BEL (\x07) BS (\x08) HT (\x09) LF (\x0A) VT (\x0B) FF (\x0C) CR (\x0D) SO (\x0E) SI (\x0F) DLE (\x10) DC1 (\x11) DC2 (\x12) DC3 (\x13) DC4 (\x14) NAK (\x15) SYN (\x16) ETB (\x17) CAN (\x18) EM (\x19) SUB (\x1A) ESC (\x1B) FS (\x1C) GS (\x1D) RS (\x1E) US (\x1F) SPACE !  # $ % ' * + , - . 0 1 2 3 4 5 6 7 8 9 : ; ? @ A B C D E F G H I J K L M N O P Q R S T U V W X Y Z [ \ ]^ _ FNC1 (\xF0) FNC2 (\xF1) FNC3 (\xF2) FNC4
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfCode128ABarcode class.
        """
        GetDllLibPdf().PdfCode128ABarcode_CreatePdfCode128ABarcode.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCode128ABarcode_CreatePdfCode128ABarcode)
        super(PdfCode128ABarcode, self).__init__(intPtr)

    @dispatch
    def __init__(self, text: str):
        """
        Initializes a new instance of the PdfCode128ABarcode class with the specified text.

        Args:
            text (str): The text to encode in the barcode.
        """
        GetDllLibPdf().PdfCode128ABarcode_CreatePdfCode128ABarcodeT.argtypes = [c_wchar_p]
        GetDllLibPdf().PdfCode128ABarcode_CreatePdfCode128ABarcodeT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfCode128ABarcode_CreatePdfCode128ABarcodeT,text)
        super(PdfCode128ABarcode, self).__init__(intPtr)