from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfColumn(SpireObject):
    """
    Represents a single column of the table.
    """

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the string format.
        """
        GetDllLibPdf().PdfColumn_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfColumn_get_StringFormat.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfColumn_get_StringFormat,self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the string format.
        """
        GetDllLibPdf().PdfColumn_set_StringFormat.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfColumn_set_StringFormat,self.Ptr, value.Ptr)

    @property
    def Width(self) -> float:
        """
        Gets or sets the width of the column.
        """
        GetDllLibPdf().PdfColumn_get_Width.argtypes = [c_void_p]
        GetDllLibPdf().PdfColumn_get_Width.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfColumn_get_Width,self.Ptr)
        return ret

    @Width.setter
    def Width(self, value: float):
        """
        Sets the width of the column.
        """
        GetDllLibPdf().PdfColumn_set_Width.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfColumn_set_Width,self.Ptr, value)

    @property
    def ColumnName(self) -> str:
        """
        Gets or sets the column name.
        """
        GetDllLibPdf().PdfColumn_get_ColumnName.argtypes = [c_void_p]
        GetDllLibPdf().PdfColumn_get_ColumnName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfColumn_get_ColumnName,self.Ptr))
        return ret

    @ColumnName.setter
    def ColumnName(self, value: str):
        """
        Sets the column name.
        """
        GetDllLibPdf().PdfColumn_set_ColumnName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfColumn_set_ColumnName,self.Ptr, value)