from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentActions(SpireObject):
    """
    Represents an action for the document.
    """

    @property
    def AfterOpenAction(self) -> 'PdfAction':
        """
        Gets or sets the action to execute when the document is opened. 

        Returns:
            A PdfAction specifying the action to be executed when documents opens in the viewer.
        """
        GetDllLibPdf().PdfDocumentActions_get_AfterOpenAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_AfterOpenAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_AfterOpenAction,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @AfterOpenAction.setter
    def AfterOpenAction(self, value: 'PdfAction'):
        """
        Sets the action to execute when the document is opened.

        Args:
            value: A PdfAction specifying the action to be executed when documents opens in the viewer.
        """
        GetDllLibPdf().PdfDocumentActions_set_AfterOpenAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_AfterOpenAction,self.Ptr, value.Ptr)

    @property
    def BeforeCloseAction(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed before the document is closed.

        Returns:
            A PdfJavaScriptAction object specifying the action to be executed before the document is closed.
        """
        GetDllLibPdf().PdfDocumentActions_get_BeforeCloseAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_BeforeCloseAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_BeforeCloseAction,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @BeforeCloseAction.setter
    def BeforeCloseAction(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed before the document is closed.

        Args:
            value: A PdfJavaScriptAction object specifying the action to be executed before the document is closed.
        """
        GetDllLibPdf().PdfDocumentActions_set_BeforeCloseAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_BeforeCloseAction,self.Ptr, value.Ptr)

    @property
    def BeforeSaveAction(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the java script action to be performed before the document is saved.

        Returns:
            A PdfJavaScriptAction object specifying the action to be executed before the document is saved.
        """
        GetDllLibPdf().PdfDocumentActions_get_BeforeSaveAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_BeforeSaveAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_BeforeSaveAction,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @BeforeSaveAction.setter
    def BeforeSaveAction(self, value: 'PdfJavaScriptAction'):
        """
        Sets the java script action to be performed before the document is saved.

        Args:
            value: A PdfJavaScriptAction object specifying the action to be executed before the document is saved.
        """
        GetDllLibPdf().PdfDocumentActions_set_BeforeSaveAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_BeforeSaveAction,self.Ptr, value.Ptr)

    @property
    def AfterSaveAction(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the jave script action to be performed after the document is saved.

        Returns:
            A PdfJavaScriptAction object specifying the action to be executed after the document is saved.
        """
        GetDllLibPdf().PdfDocumentActions_get_AfterSaveAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_AfterSaveAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_AfterSaveAction,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @AfterSaveAction.setter
    def AfterSaveAction(self, value: 'PdfJavaScriptAction'):
        """
        Sets the jave script action to be performed after the document is saved.

        Args:
            value: A PdfJavaScriptAction object specifying the action to be executed after the document is saved.
        """
        GetDllLibPdf().PdfDocumentActions_set_AfterSaveAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_AfterSaveAction,self.Ptr, value.Ptr)

    @property
    def BeforePrintAction(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed before the document is printed.

        Returns:
            A PdfJavaScriptAction object specifying the action to be executed before the document is printed.
        """
        GetDllLibPdf().PdfDocumentActions_get_BeforePrintAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_BeforePrintAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_BeforePrintAction,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @BeforePrintAction.setter
    def BeforePrintAction(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed before the document is printed.

        Args:
            value: A PdfJavaScriptAction object specifying the action to be executed before the document is printed.
        """
        GetDllLibPdf().PdfDocumentActions_set_BeforePrintAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_BeforePrintAction,self.Ptr, value.Ptr)

    @property
    def AfterPrintAction(self) -> 'PdfJavaScriptAction':
        """
        Gets or sets the action to be performed after the document is printed.

        Returns:
            A PdfJavaScriptAction object specifying the action to be executed after the document is printed.
        """
        GetDllLibPdf().PdfDocumentActions_get_AfterPrintAction.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentActions_get_AfterPrintAction.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentActions_get_AfterPrintAction,self.Ptr)
        ret = None if intPtr == None else PdfJavaScriptAction(intPtr)
        return ret

    @AfterPrintAction.setter
    def AfterPrintAction(self, value: 'PdfJavaScriptAction'):
        """
        Sets the action to be performed after the document is printed.

        Args:
            value: A PdfJavaScriptAction object specifying the action to be executed after the document is printed.
        """
        GetDllLibPdf().PdfDocumentActions_set_AfterPrintAction.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentActions_set_AfterPrintAction,self.Ptr, value.Ptr)
