from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfForm(SpireObject):
    """
    Represents interactive form of the Pdf document.
    """

    @property
    def Fields(self) -> 'PdfFormFieldCollection':
        from spire.pdf.PdfFormFieldCollection import PdfFormFieldCollection
        """
        Gets the fields.

        Returns:
            PdfFormFieldCollection: The Form fields.
        """
        GetDllLibPdf().PdfForm_get_Fields.argtypes = [c_void_p]
        GetDllLibPdf().PdfForm_get_Fields.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfForm_get_Fields,self.Ptr)
        ret = None if intPtr == None else PdfFormFieldCollection(intPtr)
        return ret

    @property
    def IsFlatten(self) -> bool:
        """
        Gets or sets a value indicating whether this is flatten.

        Returns:
            bool: True if this is flatten; otherwise, False.
        """
        GetDllLibPdf().PdfForm_get_IsFlatten.argtypes = [c_void_p]
        GetDllLibPdf().PdfForm_get_IsFlatten.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfForm_get_IsFlatten,self.Ptr)
        return ret

    @IsFlatten.setter
    def IsFlatten(self, value: bool):
        """
        Sets a value indicating whether this is flatten.

        Args:
            value (bool): True if this is flatten; otherwise, False.
        """
        GetDllLibPdf().PdfForm_set_IsFlatten.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfForm_set_IsFlatten,self.Ptr, value)

    @property
    def ReadOnly(self) -> bool:
        """
        Gets or sets a value indicating whether the form is read only.

        Returns:
            bool: True if the form is read only; otherwise, False.
        """
        GetDllLibPdf().PdfForm_get_ReadOnly.argtypes = [c_void_p]
        GetDllLibPdf().PdfForm_get_ReadOnly.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfForm_get_ReadOnly,self.Ptr)
        return ret

    @ReadOnly.setter
    def ReadOnly(self, value: bool):
        """
        Sets a value indicating whether the form is read only.

        Args:
            value (bool): True if the form is read only; otherwise, False.
        """
        GetDllLibPdf().PdfForm_set_ReadOnly.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfForm_set_ReadOnly,self.Ptr, value)

    @property
    def AutoNaming(self) -> bool:
        """
        Gets or sets a value indicating whether [field auto naming].

        Returns:
            bool: True if [field auto naming]; otherwise, False.
        """
        GetDllLibPdf().PdfForm_get_AutoNaming.argtypes = [c_void_p]
        GetDllLibPdf().PdfForm_get_AutoNaming.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfForm_get_AutoNaming,self.Ptr)
        return ret

    @AutoNaming.setter
    def AutoNaming(self, value: bool):
        """
        Sets a value indicating whether [field auto naming].

        Args:
            value (bool): True if [field auto naming]; otherwise, False.
        """
        GetDllLibPdf().PdfForm_set_AutoNaming.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfForm_set_AutoNaming,self.Ptr, value)

    @property
    def NeedAppearances(self) -> bool:
        """
        Gets or sets a value indicating whether the viewer must generate appearances for fields.

        Returns:
            bool: True if viewer must generate appearance; otherwise, False.
        """
        GetDllLibPdf().PdfForm_get_NeedAppearances.argtypes = [c_void_p]
        GetDllLibPdf().PdfForm_get_NeedAppearances.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfForm_get_NeedAppearances,self.Ptr)
        return ret

    @NeedAppearances.setter
    def NeedAppearances(self, value: bool):
        """
        Sets a value indicating whether the viewer must generate appearances for fields.

        Args:
            value (bool): True if viewer must generate appearance; otherwise, False.
        """
        GetDllLibPdf().PdfForm_set_NeedAppearances.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfForm_set_NeedAppearances,self.Ptr, value)