from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGridCellCollection(IEnumerable):
    """
    Represents a collection of PdfGridCell objects.
    """

    def get_Item(self, index: int) -> 'PdfGridCell':
        """
        Gets the PdfGridCell at the specified index.

        Args:
            index: The index of the PdfGridCell.

        Returns:
            The PdfGridCell at the specified index.
        """
        GetDllLibPdf().PdfGridCellCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfGridCellCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else PdfGridCell(intPtr)
        return ret

    @property
    def Count(self) -> int:
        """
        Gets the count of PdfGridCells in the collection.

        Returns:
            The count of PdfGridCells.
        """
        GetDllLibPdf().PdfGridCellCollection_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellCollection_get_Count.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfGridCellCollection_get_Count,self.Ptr)
        return ret

    def IndexOf(self, cell: 'PdfGridCell') -> int:
        """
        Returns the index of a particular cell in the collection.

        Args:
            cell: The cell to find the index of.

        Returns:
            The index of the cell in the collection.
        """
        intPtrcell: c_void_p = cell.Ptr

        GetDllLibPdf().PdfGridCellCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGridCellCollection_IndexOf.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfGridCellCollection_IndexOf,self.Ptr, intPtrcell)
        return ret

    def GetEnumerator(self) -> 'IEnumerator':
        """
        Returns an enumerator that iterates through the collection.

        Returns:
            An IEnumerator object.
        """
        GetDllLibPdf().PdfGridCellCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellCollection_GetEnumerator.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellCollection_GetEnumerator,self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret