from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGridStyle(PdfGridStyleBase):
    """
    Grid style
    """

    @property
    def CellSpacing(self) -> float:
        """
        Gets or sets the cell spacing.
        """
        GetDllLibPdf().PdfGridStyle_get_CellSpacing.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridStyle_get_CellSpacing.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfGridStyle_get_CellSpacing,self.Ptr)
        return ret

    @CellSpacing.setter
    def CellSpacing(self, value: float):
        """
        Sets the cell spacing.
        """
        GetDllLibPdf().PdfGridStyle_set_CellSpacing.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfGridStyle_set_CellSpacing,self.Ptr, value)

    @property
    def CellPadding(self) -> 'PdfPaddings':
        """
        Gets or sets the cell padding.
        """
        GetDllLibPdf().PdfGridStyle_get_CellPadding.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridStyle_get_CellPadding.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridStyle_get_CellPadding,self.Ptr)
        ret = None if intPtr == None else PdfPaddings(intPtr)
        return ret

    @CellPadding.setter
    def CellPadding(self, value: 'PdfPaddings'):
        """
        Sets the cell padding.
        """
        GetDllLibPdf().PdfGridStyle_set_CellPadding.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridStyle_set_CellPadding,self.Ptr, value.Ptr)

    @property
    def BorderOverlapStyle(self) -> 'PdfBorderOverlapStyle':
        """
        Gets or sets the border overlap style.
        """
        GetDllLibPdf().PdfGridStyle_get_BorderOverlapStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridStyle_get_BorderOverlapStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfGridStyle_get_BorderOverlapStyle,self.Ptr)
        objwrapped = PdfBorderOverlapStyle(ret)
        return objwrapped

    @BorderOverlapStyle.setter
    def BorderOverlapStyle(self, value: 'PdfBorderOverlapStyle'):
        """
        Sets the border overlap style.
        """
        GetDllLibPdf().PdfGridStyle_set_BorderOverlapStyle.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfGridStyle_set_BorderOverlapStyle,self.Ptr, value.value)

    @property
    def AllowHorizontalOverflow(self) -> bool:
        """
        Gets or sets a value indicating whether to allow horizontal overflow.
        """
        GetDllLibPdf().PdfGridStyle_get_AllowHorizontalOverflow.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridStyle_get_AllowHorizontalOverflow.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfGridStyle_get_AllowHorizontalOverflow,self.Ptr)
        return ret

    @AllowHorizontalOverflow.setter
    def AllowHorizontalOverflow(self, value: bool):
        """
        Sets a value indicating whether to allow horizontal overflow.
        """
        GetDllLibPdf().PdfGridStyle_set_AllowHorizontalOverflow.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfGridStyle_set_AllowHorizontalOverflow,self.Ptr, value)

    @property
    def HorizontalOverflowType(self) -> 'PdfHorizontalOverflowType':
        """
        Gets or sets the type of the horizontal overflow.
        """
        GetDllLibPdf().PdfGridStyle_get_HorizontalOverflowType.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridStyle_get_HorizontalOverflowType.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfGridStyle_get_HorizontalOverflowType,self.Ptr)
        objwrapped = PdfHorizontalOverflowType(ret)
        return objwrapped

    @HorizontalOverflowType.setter
    def HorizontalOverflowType(self, value: 'PdfHorizontalOverflowType'):
        """
        Sets the type of the horizontal overflow.
        """
        GetDllLibPdf().PdfGridStyle_set_HorizontalOverflowType.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfGridStyle_set_HorizontalOverflowType,self.Ptr, value.value)