from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfHtmlLayoutFormat(SpireObject):
    """
    Represents the layout format of a PDF HTML element.
    """

    @property
    def Layout(self) -> 'PdfLayoutType':
        """
        Gets or sets the layout type of the element.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_Layout.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_Layout.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_Layout,self.Ptr)
        objwrapped = PdfLayoutType(ret)
        return objwrapped

    @Layout.setter
    def Layout(self, value: 'PdfLayoutType'):
        """
        Sets the layout type of the element.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_Layout.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_Layout,self.Ptr, value.value)

    @property
    def FitToPage(self) -> 'Clip':
        """
        Gets or sets the clip type for fitting the HTML view to the PDF page.
        If the HTML view is larger than the PDF page, it will be zoomed out to fit the page.
        If the HTML view is smaller, it will not be zoomed in.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToPage.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToPage.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToPage,self.Ptr)
        objwrapped = Clip(ret)
        return objwrapped

    @FitToPage.setter
    def FitToPage(self, value: 'Clip'):
        """
        Sets the clip type for fitting the HTML view to the PDF page.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_FitToPage.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_FitToPage,self.Ptr, value.value)

    @property
    def FitToHtml(self) -> 'Clip':
        """
        Gets or sets the clip type for resizing the PDF page to fit the HTML view.
        If the HTML view is larger than the page, the page will be resized to fit the view.
        If the HTML view is smaller, the page will not be resized.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToHtml.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToHtml.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_FitToHtml,self.Ptr)
        objwrapped = Clip(ret)
        return objwrapped

    @FitToHtml.setter
    def FitToHtml(self, value: 'Clip'):
        """
        Sets the clip type for resizing the PDF page to fit the HTML view.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_FitToHtml.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_FitToHtml,self.Ptr, value.value)

    @property
    def TrimPage(self) -> 'Clip':
        """
        Gets or sets the clip type for trimming the PDF page to fit the HTML view.
        If the HTML view is smaller than the page, the page will be trimmed to fit the view.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_TrimPage.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_TrimPage.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_TrimPage,self.Ptr)
        objwrapped = Clip(ret)
        return objwrapped

    @TrimPage.setter
    def TrimPage(self, value: 'Clip'):
        """
        Sets the clip type for trimming the PDF page to fit the HTML view.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_TrimPage.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_TrimPage,self.Ptr, value.value)

    @property
    def LoadHtmlTimeout(self) -> int:
        """
        Gets or sets the maximum time in milliseconds to wait for the completion of loading HTML.
        The default value is 30000.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_LoadHtmlTimeout.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_LoadHtmlTimeout.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_LoadHtmlTimeout,self.Ptr)
        return ret

    @LoadHtmlTimeout.setter
    def LoadHtmlTimeout(self, value: int):
        """
        Sets the maximum time in milliseconds to wait for the completion of loading HTML.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_LoadHtmlTimeout.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_LoadHtmlTimeout,self.Ptr, value)

    @property
    def IsWaiting(self) -> bool:
        """
        Gets or sets whether the web browser is waiting for HTML to load.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_IsWaiting.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_IsWaiting.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_IsWaiting,self.Ptr)
        return ret

    @IsWaiting.setter
    def IsWaiting(self, value: bool):
        """
        Sets whether the web browser is waiting for HTML to load.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_IsWaiting.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_IsWaiting,self.Ptr, value)

    @property
    def WaitingTime(self) -> int:
        """
        Gets or sets the waiting time in milliseconds for the web browser to load HTML.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_get_WaitingTime.argtypes = [c_void_p]
        GetDllLibPdf().PdfHtmlLayoutFormat_get_WaitingTime.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_get_WaitingTime,self.Ptr)
        return ret

    @WaitingTime.setter
    def WaitingTime(self, value: int):
        """
        Sets the waiting time in milliseconds for the web browser to load HTML.
        """
        GetDllLibPdf().PdfHtmlLayoutFormat_set_WaitingTime.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfHtmlLayoutFormat_set_WaitingTime,self.Ptr, value)