from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfKnownColorSpace(PdfColorSpaces):
    """
    Represents an indexed colorspace.
    """

    @property
    def BaseColorSpace(self) -> 'PdfColorSpaces':
        """
        Gets or sets the base colorspace. 

        Returns:
            The color space in which the values in the color table are to be interpreted.
        """
        GetDllLibPdf().PdfKnownColorSpace_get_BaseColorSpace.argtypes = [c_void_p]
        GetDllLibPdf().PdfKnownColorSpace_get_BaseColorSpace.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfKnownColorSpace_get_BaseColorSpace,self.Ptr)
        ret = None if intPtr == None else PdfColorSpaces(intPtr)
        return ret

    @BaseColorSpace.setter
    def BaseColorSpace(self, value: 'PdfColorSpaces'):
        """
        Sets the base colorspace.

        Args:
            value: The color space in which the values in the color table are to be interpreted.
        """
        GetDllLibPdf().PdfKnownColorSpace_set_BaseColorSpace.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfKnownColorSpace_set_BaseColorSpace,self.Ptr, value.Ptr)

    @property
    def MaxColorIndex(self) -> int:
        """
        Gets or sets the index of the max color.

        Returns:
            The maximum index that can be used to access the values in the color table.
        """
        GetDllLibPdf().PdfKnownColorSpace_get_MaxColorIndex.argtypes = [c_void_p]
        GetDllLibPdf().PdfKnownColorSpace_get_MaxColorIndex.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfKnownColorSpace_get_MaxColorIndex,self.Ptr)
        return ret

    @MaxColorIndex.setter
    def MaxColorIndex(self, value: int):
        """
        Sets the index of the max color.

        Args:
            value: The maximum index that can be used to access the values in the color table.
        """
        GetDllLibPdf().PdfKnownColorSpace_set_MaxColorIndex.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfKnownColorSpace_set_MaxColorIndex,self.Ptr, value)
