from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayoutResult(SpireObject):
    """
    Represents the result of a layout operation in a PDF document.
    """

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page associated with the layout result.
        
        Returns:
            PdfPageBase: The page associated with the layout result.
        """
        from spire.pdf.PdfPageBase import PdfPageBase
        GetDllLibPdf().PdfLayoutResult_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayoutResult_get_Page.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutResult_get_Page,self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @property
    def Bounds(self) -> 'RectangleF':
        """
        Gets the bounding rectangle of the layout result.
        
        Returns:
            RectangleF: The bounding rectangle of the layout result.
        """
        GetDllLibPdf().PdfLayoutResult_get_Bounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayoutResult_get_Bounds.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutResult_get_Bounds,self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret