from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPaddings(SpireObject):
    """
    Represents the padding of a PDF object.
    """

    @property
    def Left(self) -> float:
        """
        Gets or sets the left padding.
        """
        GetDllLibPdf().PdfPaddings_get_Left.argtypes = [c_void_p]
        GetDllLibPdf().PdfPaddings_get_Left.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPaddings_get_Left,self.Ptr)
        return ret

    @Left.setter
    def Left(self, value: float):
        """
        Sets the left padding.
        """
        GetDllLibPdf().PdfPaddings_set_Left.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPaddings_set_Left,self.Ptr, value)

    @property
    def Right(self) -> float:
        """
        Gets or sets the right padding.
        """
        GetDllLibPdf().PdfPaddings_get_Right.argtypes = [c_void_p]
        GetDllLibPdf().PdfPaddings_get_Right.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPaddings_get_Right,self.Ptr)
        return ret

    @Right.setter
    def Right(self, value: float):
        """
        Sets the right padding.
        """
        GetDllLibPdf().PdfPaddings_set_Right.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPaddings_set_Right,self.Ptr, value)

    @property
    def Top(self) -> float:
        """
        Gets or sets the top padding.
        """
        GetDllLibPdf().PdfPaddings_get_Top.argtypes = [c_void_p]
        GetDllLibPdf().PdfPaddings_get_Top.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPaddings_get_Top,self.Ptr)
        return ret

    @Top.setter
    def Top(self, value: float):
        """
        Sets the top padding.
        """
        GetDllLibPdf().PdfPaddings_set_Top.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPaddings_set_Top,self.Ptr, value)

    @property
    def Bottom(self) -> float:
        """
        Gets or sets the bottom padding.
        """
        GetDllLibPdf().PdfPaddings_get_Bottom.argtypes = [c_void_p]
        GetDllLibPdf().PdfPaddings_get_Bottom.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPaddings_get_Bottom,self.Ptr)
        return ret

    @Bottom.setter
    def Bottom(self, value: float):
        """
        Sets the bottom padding.
        """
        GetDllLibPdf().PdfPaddings_set_Bottom.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPaddings_set_Bottom,self.Ptr, value)

    @property
    def All(self) -> float:
        """
        Gets or sets the padding for all sides.
        """
        return 0

    @All.setter
    def All(self, value: float):
        """
        Sets the padding for all sides.
        """
        GetDllLibPdf().PdfPaddings_set_All.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPaddings_set_All,self.Ptr, value)