from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

#from spire.pdf.SimpleTextExtractionStrategy import SimpleTextExtractionStrategy 
#from spire.pdf.PdfTextFindCollection import PdfTextFindCollection 

class PdfPageBase (SpireObject) :
    """
    The base class for all pages.
    """
   # @dispatch

   # def ExtractImages(self)->List[Image]:
   #     """
   #     Extracts images from the given PDF Page.
   #         The name of a image in the resources save in the Tag attribute of the iamge.

			#Returns:
   #         List[Image]: Returns the extracted image as Image[].
   #     """			
   #     GetDllLibPdf().PdfPageBase_ExtractImages.argtypes=[c_void_p]
   #     GetDllLibPdf().PdfPageBase_ExtractImages.restype=IntPtrArray
   #     intPtrArray = CallCFunction(GetDllLibPdf().PdfPageBase_ExtractImages,self.Ptr)
   #     ret = GetObjVectorFromArray(intPtrArray, Image)
   #     return ret


    #@dispatch

    #def ExtractImages(self ,processImage:bool)->List[Image]:
    #    """
    #    Extracts images from the given PDF Page. and image is not processed.
    #        The name of a image in the resources save in the Tag attribute of the image.

    #    Args:
    #        processImage (bool): processImage or not

    #    Returns:
    #        List[Image]: Returns the extracted image as Image[].
    #    """        
    #    GetDllLibPdf().PdfPageBase_ExtractImagesP.argtypes=[c_void_p ,c_bool]
    #    GetDllLibPdf().PdfPageBase_ExtractImagesP.restype=IntPtrArray
    #    intPtrArray = CallCFunction(GetDllLibPdf().PdfPageBase_ExtractImagesP,self.Ptr, processImage)
    #    ret = GetObjVectorFromArray(intPtrArray, Image)
    #    return ret


    @dispatch

    def DeleteImage(self ,image:PdfImageInfo):
        """
        Delete an image.
            The value of the image's Tag attribute is the name of the image in the resources.
            If the value of Tag is null,the sample image is an inline image type.

        Args:
            image (PdfImageInfo): The image to be delete.
        """ 		
        intPtrimage:c_void_p = image.Ptr

        GetDllLibPdf().PdfPageBase_DeleteImage.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_DeleteImage,self.Ptr, intPtrimage)

    @dispatch

    def DeleteImage(self ,image:PdfImageInfo,deleteResource:bool):
        """
        Delete an image.
            The value of the image's Tag attribute is the name of the image in the resources.
            If the value of Tag is null,the sample image is an inline image type.
            Warning : You must make sure that the image resource you are removing is the only
            one referenced,otherwise an error will occur.

        Args:
            image (PdfImageInfo): The image to be delete.
			deleteResource (bool): whether to delete the image resource.
        """		
        intPtrimage:c_void_p = image.Ptr

        GetDllLibPdf().PdfPageBase_DeleteImageID.argtypes=[c_void_p ,c_void_p,c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_DeleteImageID,self.Ptr, intPtrimage,deleteResource)

    @dispatch

    def DeleteImage(self ,imageIndex:int):
        """
        Delete an image by index in a page.

        Args:
            imageIndex (int): The image index.
        """	        
        GetDllLibPdf().PdfPageBase_DeleteImageI.argtypes=[c_void_p ,c_int]
        CallCFunction(GetDllLibPdf().PdfPageBase_DeleteImageI,self.Ptr, imageIndex)


    def TryCompressImage(self ,imgIndex:int)->bool:
        """
        Try to compress images(except inline image).

        Args:
            index (int): The image index.

        Returns:
            bool: If success, return true; otherwise false.
        """        
        GetDllLibPdf().PdfPageBase_TryCompressImage.argtypes=[c_void_p ,c_int]
        GetDllLibPdf().PdfPageBase_TryCompressImage.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_TryCompressImage,self.Ptr, imgIndex)
        return ret


    def SetTabOrder(self ,tabOrder:'TabOrder'):
        """
        Set tab order.

        Args:
            tabOrder (TabOrder): The order name.
        """		
        enumtabOrder:c_int = tabOrder.value

        GetDllLibPdf().PdfPageBase_SetTabOrder.argtypes=[c_void_p ,c_int]
        CallCFunction(GetDllLibPdf().PdfPageBase_SetTabOrder,self.Ptr, enumtabOrder)

    #@dispatch

    #def LoadFromRTF(self ,rtf:str,width:float,IsSplitLine:bool):
    #    """
    #<summary>
    #    Insert rich text to page
    #</summary>
    #<param name="rtf">rich text</param>
    #<param name="width">width</param>
    #<param name="IsSplitLine">IsSplitLine</param>
    #    """
        
    #    GetDllLibPdf().PdfPageBase_LoadFromRTF.argtypes=[c_void_p ,c_wchar_p,c_float,c_bool]
    #    CallCFunction(GetDllLibPdf().PdfPageBase_LoadFromRTF,self.Ptr, rtf,width,IsSplitLine)

    #@dispatch

    #def LoadFromRTF(self ,rtf:str,width:float,IsSplitLine:bool,point:PointF):
    #    """
    #<summary>
    #    Insert rich text to page
    #</summary>
    #<param name="rtf">rich text</param>
    #<param name="width">width</param>
    #<param name="IsSplitLine">IsSplitLine</param>
    #<param name="point">Draw text x,y point</param>
    #    """
    #    intPtrpoint:c_void_p = point.Ptr

    #    GetDllLibPdf().PdfPageBase_LoadFromRTFRWIP.argtypes=[c_void_p ,c_wchar_p,c_float,c_bool,c_void_p]
    #    CallCFunction(GetDllLibPdf().PdfPageBase_LoadFromRTFRWIP,self.Ptr, rtf,width,IsSplitLine,intPtrpoint)

    #@dispatch

    #def LoadFromRTF(self ,rtf:str,width:float,height:float,IsSplitLine:bool):
    #    """
    #<summary>
    #    Insert rich text to page
    #</summary>
    #<param name="rtf">rich text</param>
    #<param name="width">width</param>
    #<param name="IsSplitLine">IsSplitLine</param>
    #    """
        
    #    GetDllLibPdf().PdfPageBase_LoadFromRTFRWHI.argtypes=[c_void_p ,c_wchar_p,c_float,c_float,c_bool]
    #    CallCFunction(GetDllLibPdf().PdfPageBase_LoadFromRTFRWHI,self.Ptr, rtf,width,height,IsSplitLine)

    #@dispatch

    #def LoadFromRTF(self ,rtf:str,width:float,height:float,IsSplitLine:bool,point:PointF):
    #    """
    #<summary>
    #    Insert rich text to page
    #</summary>
    #<param name="rtf">rich text</param>
    #<param name="width">width</param>
    #<param name="IsSplitLine">IsSplitLine</param>
    #<param name="point">Draw text x,y point</param>
    #    """
    #    intPtrpoint:c_void_p = point.Ptr

    #    GetDllLibPdf().PdfPageBase_LoadFromRTFRWHIP.argtypes=[c_void_p ,c_wchar_p,c_float,c_float,c_bool,c_void_p]
    #    CallCFunction(GetDllLibPdf().PdfPageBase_LoadFromRTFRWHIP,self.Ptr, rtf,width,height,IsSplitLine,intPtrpoint)

#
#    def add_BeginSave(self ,value:'EventHandler'):
#        """
#
#        """
#        intPtrvalue:c_void_p = value.Ptr
#
#        GetDllLibPdf().PdfPageBase_add_BeginSave.argtypes=[c_void_p ,c_void_p]
#        CallCFunction(GetDllLibPdf().PdfPageBase_add_BeginSave,self.Ptr, intPtrvalue)


#
#    def remove_BeginSave(self ,value:'EventHandler'):
#        """
#
#        """
#        intPtrvalue:c_void_p = value.Ptr
#
#        GetDllLibPdf().PdfPageBase_remove_BeginSave.argtypes=[c_void_p ,c_void_p]
#        CallCFunction(GetDllLibPdf().PdfPageBase_remove_BeginSave,self.Ptr, intPtrvalue)


    @property
    def AllowContainAllDocTemplates(self)->bool:
        """

        """
        GetDllLibPdf().PdfPageBase_get_AllowContainAllDocTemplates.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AllowContainAllDocTemplates.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_AllowContainAllDocTemplates,self.Ptr)
        return ret

    @AllowContainAllDocTemplates.setter
    def AllowContainAllDocTemplates(self, value:bool):
        GetDllLibPdf().PdfPageBase_set_AllowContainAllDocTemplates.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AllowContainAllDocTemplates,self.Ptr, value)

    @property
    def AllowContainLeftDocTemplates(self)->bool:
        """

        """
        GetDllLibPdf().PdfPageBase_get_AllowContainLeftDocTemplates.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AllowContainLeftDocTemplates.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_AllowContainLeftDocTemplates,self.Ptr)
        return ret

    @AllowContainLeftDocTemplates.setter
    def AllowContainLeftDocTemplates(self, value:bool):
        GetDllLibPdf().PdfPageBase_set_AllowContainLeftDocTemplates.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AllowContainLeftDocTemplates,self.Ptr, value)

    @property
    def AllowContainRightDocTemplates(self)->bool:
        """

        """
        GetDllLibPdf().PdfPageBase_get_AllowContainRightDocTemplates.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AllowContainRightDocTemplates.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_AllowContainRightDocTemplates,self.Ptr)
        return ret

    @AllowContainRightDocTemplates.setter
    def AllowContainRightDocTemplates(self, value:bool):
        GetDllLibPdf().PdfPageBase_set_AllowContainRightDocTemplates.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AllowContainRightDocTemplates,self.Ptr, value)

    @property
    def AllowContainTopDocTemplates(self)->bool:
        """

        """
        GetDllLibPdf().PdfPageBase_get_AllowContainTopDocTemplates.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AllowContainTopDocTemplates.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_AllowContainTopDocTemplates,self.Ptr)
        return ret

    @AllowContainTopDocTemplates.setter
    def AllowContainTopDocTemplates(self, value:bool):
        GetDllLibPdf().PdfPageBase_set_AllowContainTopDocTemplates.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AllowContainTopDocTemplates,self.Ptr, value)

    @property
    def AllowContainBottomDocTemplates(self)->bool:
        """

        """
        GetDllLibPdf().PdfPageBase_get_AllowContainBottomDocTemplates.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AllowContainBottomDocTemplates.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_AllowContainBottomDocTemplates,self.Ptr)
        return ret

    @AllowContainBottomDocTemplates.setter
    def AllowContainBottomDocTemplates(self, value:bool):
        GetDllLibPdf().PdfPageBase_set_AllowContainBottomDocTemplates.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AllowContainBottomDocTemplates,self.Ptr, value)

    @property

    def CropBox(self)->'RectangleF':
        """
        Returns the visible region of the page.
        """
        GetDllLibPdf().PdfPageBase_get_CropBox.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_CropBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_CropBox,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret

    @CropBox.setter
    def CropBox(self, value:'RectangleF'):
        GetDllLibPdf().PdfPageBase_set_CropBox.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_CropBox,self.Ptr, value.Ptr)

    @property

    def BleedBox(self)->'RectangleF':
        """
        Returns page region after clipping.
        """
        GetDllLibPdf().PdfPageBase_get_BleedBox.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_BleedBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_BleedBox,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @property

    def MediaBox(self)->'RectangleF':
        """
        Returns page region mediabox.
        """
        GetDllLibPdf().PdfPageBase_get_MediaBox.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_MediaBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_MediaBox,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @property

    def TrimBox(self)->'RectangleF':
        """
        Returns page region after trimming.
        """
        GetDllLibPdf().PdfPageBase_get_TrimBox.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_TrimBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_TrimBox,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @property

    def ArtBox(self)->'RectangleF':
        """
        Returns page region containing content.
        """
        GetDllLibPdf().PdfPageBase_get_ArtBox.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_ArtBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_ArtBox,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret

    @property
    def Annotations(self)->'PdfAnnotationCollection':
        from spire.pdf.PdfAnnotationCollection import PdfAnnotationCollection
        """
        Gets the field collection.
        """
        GetDllLibPdf().PdfPageBase_get_Annotations.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Annotations.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_Annotations,self.Ptr)
        ret = None if intPtr==None else PdfAnnotationCollection(intPtr)
        return ret

    @property
    def AnnotationsWidget(self)->'PdfAnnotationCollection':
        from spire.pdf.PdfAnnotationCollection import PdfAnnotationCollection
        """
        Gets the field collection.
        """
        GetDllLibPdf().PdfPageBase_get_AnnotationsWidget.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_AnnotationsWidget.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_AnnotationsWidget,self.Ptr)
        ret = None if intPtr==None else PdfAnnotationCollection(intPtr)
        return ret


    @AnnotationsWidget.setter
    def AnnotationsWidget(self, value:'PdfAnnotationCollection'):
        GetDllLibPdf().PdfPageBase_set_AnnotationsWidget.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_AnnotationsWidget,self.Ptr, value.Ptr)

    @property

    def PagePieceInfo(self)->'PdfPieceInfo':
        """
        Get the page piece info.
        """
        GetDllLibPdf().PdfPageBase_get_PagePieceInfo.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_PagePieceInfo.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_PagePieceInfo,self.Ptr)
        ret = None if intPtr==None else PdfPieceInfo(intPtr)
        return ret


    @PagePieceInfo.setter
    def PagePieceInfo(self, value:'PdfPieceInfo'):
        GetDllLibPdf().PdfPageBase_set_PagePieceInfo.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_PagePieceInfo,self.Ptr, value.Ptr)

    @property

    def BackgroundColor(self)->'Color':
        """
        Gets or sets page's background color.
        """
        GetDllLibPdf().PdfPageBase_get_BackgroundColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_BackgroundColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_BackgroundColor,self.Ptr)
        ret = None if intPtr==None else Color(intPtr)
        return ret


    @BackgroundColor.setter
    def BackgroundColor(self, value:'Color'):
        GetDllLibPdf().PdfPageBase_set_BackgroundColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_BackgroundColor,self.Ptr, value.Ptr)

    @property
    def BackgroudOpacity(self)->float:
        """

        """
        GetDllLibPdf().PdfPageBase_get_BackgroudOpacity.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_BackgroudOpacity.restype=c_float
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_BackgroudOpacity,self.Ptr)
        return ret

    @BackgroudOpacity.setter
    def BackgroudOpacity(self, value:float):
        GetDllLibPdf().PdfPageBase_set_BackgroudOpacity.argtypes=[c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_BackgroudOpacity,self.Ptr, value)

    @property

    def BackgroundRegion(self)->'RectangleF':
        """
        The position and size of the background 
        """
        GetDllLibPdf().PdfPageBase_get_BackgroundRegion.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_BackgroundRegion.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_BackgroundRegion,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @BackgroundRegion.setter
    def BackgroundRegion(self, value:'RectangleF'):
        GetDllLibPdf().PdfPageBase_set_BackgroundRegion.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_BackgroundRegion,self.Ptr, value.Ptr)

    @property

    def ImagesInfo(self)->List['PdfImageInfo']:
        """
        Gets the information about the extracted image.
        """
        GetDllLibPdf().PdfPageBase_get_ImagesInfo.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_ImagesInfo.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfPageBase_get_ImagesInfo,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, PdfImageInfo)
        return ret


    @property

    def Canvas(self)->'PdfCanvas':
        """
        Gets the graphics of the .
        """
        GetDllLibPdf().PdfPageBase_get_Canvas.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Canvas.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_Canvas,self.Ptr)
        ret = None if intPtr==None else PdfCanvas(intPtr)
        return ret


    @property

    def Section(self)->'PdfSection':
        """
        Gets the parent section of the page.
        """
        GetDllLibPdf().PdfPageBase_get_Section.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Section.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_Section,self.Ptr)
        ret = None if intPtr==None else PdfSection(intPtr)
        return ret


    @property

    def Document(self)->'PdfDocumentBase':
        """

        """
        GetDllLibPdf().PdfPageBase_get_Document.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Document.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_Document,self.Ptr)
        ret = None if intPtr==None else PdfDocumentBase(intPtr)
        return ret


    @property
    def DefaultLayerIndex(self)->int:
        """
        Gets or sets index of the default layer.
        """
        GetDllLibPdf().PdfPageBase_get_DefaultLayerIndex.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_DefaultLayerIndex.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_DefaultLayerIndex,self.Ptr)
        return ret

    @DefaultLayerIndex.setter
    def DefaultLayerIndex(self, value:int):
        GetDllLibPdf().PdfPageBase_set_DefaultLayerIndex.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_DefaultLayerIndex,self.Ptr, value)

    @property

    def Size(self)->'SizeF':
        """
        Gets the size of the page.
        """
        GetDllLibPdf().PdfPageBase_get_Size.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Size.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_Size,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @property

    def ActualSize(self)->'SizeF':
        """
        Gets the actual size of the page.
        """
        GetDllLibPdf().PdfPageBase_get_ActualSize.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_ActualSize.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_ActualSize,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @property

    def Rotation(self)->'PdfPageRotateAngle':
        """

        """
        GetDllLibPdf().PdfPageBase_get_Rotation.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_Rotation.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_get_Rotation,self.Ptr)
        objwraped = PdfPageRotateAngle(ret)
        return objwraped

    @Rotation.setter
    def Rotation(self, value:'PdfPageRotateAngle'):
        GetDllLibPdf().PdfPageBase_set_Rotation.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_Rotation,self.Ptr, value.value)

    @property

    def BackgroundImage(self)->'Stream':
        """
        Gets or sets page's background image.
        """
        GetDllLibPdf().PdfPageBase_get_BackgroundImage.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_BackgroundImage.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_get_BackgroundImage,self.Ptr)
        ret = None if intPtr==None else Stream(intPtr)
        return ret


    @BackgroundImage.setter
    def BackgroundImage(self, value:'Stream'):
        GetDllLibPdf().PdfPageBase_set_BackgroundImage.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_set_BackgroundImage,self.Ptr, value.Ptr)

    @property

    def PageLabel(self)->str:
        """
        Get the page label.
        """
        GetDllLibPdf().PdfPageBase_get_PageLabel.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_get_PageLabel.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfPageBase_get_PageLabel,self.Ptr))
        return ret


    def IsBlank(self)->bool:
        """
        Returns page is blank flag for page's content.
        """
        GetDllLibPdf().PdfPageBase_IsBlank.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_IsBlank.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPageBase_IsBlank,self.Ptr)
        return ret


    def GetClientSize(self)->'SizeF':
        """
        Returns a page size reduced by page margins and page template dimensions.
		    It's the actual size of the page where some output can be performed.

        Returns:
            SizeF: Returns a page size reduced by page margins and page template dimensions.
        """		
        GetDllLibPdf().PdfPageBase_GetClientSize.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_GetClientSize.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_GetClientSize,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @dispatch

    def ReplaceImage(self ,imageIndex:int,image:PdfImage):
        """
        Replace the Image at index's Position.

        Args:
            imageIndex (int): The index of original image.
			image (PdfImage): The new replace image.
        """		
        intPtrimage:c_void_p = image.Ptr

        GetDllLibPdf().PdfPageBase_ReplaceImage.argtypes=[c_void_p ,c_int,c_void_p]
        CallCFunction(GetDllLibPdf().PdfPageBase_ReplaceImage,self.Ptr, imageIndex,intPtrimage)

    #@dispatch

    #def ReplaceImage(self ,originalImage:Image,image:PdfImage):
    #    """
    #<summary>
    #    Replace the Image through the original image.   
    #</summary>
    #<param name="originalImage">The original image</param>
    #<param name="image">The New Replace image</param>
    #    """
    #    intPtroriginalImage:c_void_p = originalImage.Ptr
    #    intPtrimage:c_void_p = image.Ptr

    #    GetDllLibPdf().PdfPageBase_ReplaceImageOI.argtypes=[c_void_p ,c_void_p,c_void_p]
    #    CallCFunction(GetDllLibPdf().PdfPageBase_ReplaceImageOI,self.Ptr, intPtroriginalImage,intPtrimage)


    def CreateTemplate(self)->'PdfTemplate':
        """
        Creates a template from page content and all annotation appearances.

        Returns:
            PdfTemplate: The created template.
        """
        GetDllLibPdf().PdfPageBase_CreateTemplate.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageBase_CreateTemplate.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageBase_CreateTemplate,self.Ptr)
        ret = None if intPtr==None else PdfTemplate(intPtr)
        return ret
