from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPageTransition(SpireObject):
    """
    Represents parameters how to display the page in the presentation mode.
    """

    @property
    def Style(self) -> 'PdfTransitionStyle':
        """
        Gets or sets the transition style to use when moving to this page from another 
        during a presentation.
        """
        GetDllLibPdf().PdfPageTransition_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Style.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Style,self.Ptr)
        objwrapped = PdfTransitionStyle(ret)
        return objwrapped

    @Style.setter
    def Style(self, value: 'PdfTransitionStyle'):
        """
        Sets the transition style to use when moving to this page from another 
        during a presentation.
        """
        GetDllLibPdf().PdfPageTransition_set_Style.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Style,self.Ptr, value.value)

    @property
    def Duration(self) -> float:
        """
        Gets or sets the duration of the transition effect, in seconds.
        """
        GetDllLibPdf().PdfPageTransition_get_Duration.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Duration.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Duration,self.Ptr)
        return ret

    @Duration.setter
    def Duration(self, value: float):
        """
        Sets the duration of the transition effect, in seconds.
        """
        GetDllLibPdf().PdfPageTransition_set_Duration.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Duration,self.Ptr, value)

    @property
    def Dimension(self) -> 'PdfTransitionDimension':
        """
        Gets or sets the dimension in which the specified transition effect occurs.
        """
        GetDllLibPdf().PdfPageTransition_get_Dimension.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Dimension.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Dimension,self.Ptr)
        objwrapped = PdfTransitionDimension(ret)
        return objwrapped

    @Dimension.setter
    def Dimension(self, value: 'PdfTransitionDimension'):
        """
        Sets the dimension in which the specified transition effect occurs.
        """
        GetDllLibPdf().PdfPageTransition_set_Dimension.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Dimension,self.Ptr, value.value)

    @property
    def Motion(self) -> 'PdfTransitionMotion':
        """
        Gets or sets the the direction of motion for the specified transition effect.
        """
        GetDllLibPdf().PdfPageTransition_get_Motion.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Motion.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Motion,self.Ptr)
        objwrapped = PdfTransitionMotion(ret)
        return objwrapped

    @Motion.setter
    def Motion(self, value: 'PdfTransitionMotion'):
        """
        Sets the the direction of motion for the specified transition effect.
        """
        GetDllLibPdf().PdfPageTransition_set_Motion.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Motion,self.Ptr, value.value)

    @property
    def Direction(self) -> 'PdfTransitionDirection':
        """
        The direction in which the specified transition effect moves, expressed in degrees counter 
        clockwise starting from a left-to-right direction. (This differs from the page objects 
        Rotate property, which is measured clockwise from the top.)
        """
        GetDllLibPdf().PdfPageTransition_get_Direction.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Direction.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Direction,self.Ptr)
        objwrapped = PdfTransitionDirection(ret)
        return objwrapped

    @Direction.setter
    def Direction(self, value: 'PdfTransitionDirection'):
        """
        Sets the direction in which the specified transition effect moves, expressed in degrees counter 
        clockwise starting from a left-to-right direction. (This differs from the page objects 
        Rotate property, which is measured clockwise from the top.)
        """
        GetDllLibPdf().PdfPageTransition_set_Direction.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Direction,self.Ptr, value.value)

    @property
    def Scale(self) -> float:
        """
        Gets or sets the starting or ending scale at which the changes are drawn. 
        If Motion property specifies an inward transition, the scale of the changes drawn progresses 
        from Scale to 1.0 over the course of the transition. If Motion specifies an outward 
        transition, the scale of the changes drawn progresses from 1.0 to Scale over the course 
        of the transition.
        """
        GetDllLibPdf().PdfPageTransition_get_Scale.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_Scale.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_Scale,self.Ptr)
        return ret

    @Scale.setter
    def Scale(self, value: float):
        """
        Sets the starting or ending scale at which the changes are drawn. 
        If Motion property specifies an inward transition, the scale of the changes drawn progresses 
        from Scale to 1.0 over the course of the transition. If Motion specifies an outward 
        transition, the scale of the changes drawn progresses from 1.0 to Scale over the course 
        of the transition.
        """
        GetDllLibPdf().PdfPageTransition_set_Scale.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_Scale,self.Ptr, value)

    @property
    def PageDuration(self) -> float:
        """
        Gets or sets The pages display duration (also called its advance timing): the maximum 
        length of time, in seconds, that the page is displayed during presentations before 
        the viewer application automatically advances to the next page. By default, 
        the viewer does not advance automatically.
        """
        GetDllLibPdf().PdfPageTransition_get_PageDuration.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_get_PageDuration.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfPageTransition_get_PageDuration,self.Ptr)
        return ret

    @PageDuration.setter
    def PageDuration(self, value: float):
        """
        Sets The pages display duration (also called its advance timing): the maximum 
        length of time, in seconds, that the page is displayed during presentations before 
        the viewer application automatically advances to the next page. By default, 
        the viewer does not advance automatically.
        """
        GetDllLibPdf().PdfPageTransition_set_PageDuration.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfPageTransition_set_PageDuration,self.Ptr, value)

    def Clone(self) -> 'SpireObject':
        """
        Creates a new object that is a copy of the current instance.
        """
        GetDllLibPdf().PdfPageTransition_Clone.argtypes = [c_void_p]
        GetDllLibPdf().PdfPageTransition_Clone.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPageTransition_Clone,self.Ptr)
        ret = None if intPtr == None else SpireObject(intPtr)
        return ret