from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfRadioButtonItemCollection(PdfCollection):
    """
    Represents collection of radio buttons items.
    """

    def Add(self, item: 'PdfRadioButtonListItem') -> int:
        """
        Adds the specified item.

        Args:
            item: The object to be added to collection.

        Returns:
            The index of the added field.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfRadioButtonItemCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadioButtonItemCollection_Add.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_Add,self.Ptr, intPtritem)
        return ret


    def Insert(self, index: int, item: 'PdfRadioButtonListItem'):
        """
        Inserts an item at the specified index.

        Args:
            index: The index where to insert the new item.
            item: A object to be added to collection.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfRadioButtonItemCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_Insert,self.Ptr, index, intPtritem)


    def Remove(self, item: 'PdfRadioButtonListItem'):
        """
        Removes the specified item from the collection.

        Args:
            item: The object which is to be removed from the collection.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfRadioButtonItemCollection_Remove.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_Remove,self.Ptr, intPtritem)


    def RemoveAt(self, index: int):
        """
        Removes the item at the specified position.

        Args:
            index: The index where to remove the item.
        """
        GetDllLibPdf().PdfRadioButtonItemCollection_RemoveAt.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_RemoveAt,self.Ptr, index)


    def IndexOf(self, item: 'PdfRadioButtonListItem') -> int:
        """
        Gets the index of the item within the collection.

        Args:
            item: A object whose index is requested.

        Returns:
            Index of the item with the collection.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfRadioButtonItemCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadioButtonItemCollection_IndexOf.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_IndexOf,self.Ptr, intPtritem)
        return ret


    def Contains(self, item: 'PdfRadioButtonListItem') -> bool:
        """
        Determines whether the collection contains the specified item.

        Args:
            item: Check whether object is exists in the collection or not.

        Returns:
            True if collection contains specified item; otherwise, False.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfRadioButtonItemCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadioButtonItemCollection_Contains.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_Contains,self.Ptr, intPtritem)
        return ret

    def Clear(self):
        """
        Clears the item collection.
        """
        GetDllLibPdf().PdfRadioButtonItemCollection_Clear.argtypes = [c_void_p]
        CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_Clear,self.Ptr)


    def get_Item(self, index: int) -> 'PdfRadioButtonListItem':
        """
        Gets the at the specified index.

        Returns:
            Item at the specified position.
        """
        GetDllLibPdf().PdfRadioButtonItemCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfRadioButtonItemCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRadioButtonItemCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else PdfRadioButtonListItem(intPtr)
        return ret