from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfRadioButtonListField(PdfField):
    """
    Represents radio button field in the PDF form.
    """
    @dispatch
    def __init__(self, page: PdfPageBase, name: str):
        """
        Initializes a new instance of the PdfRadioButtonListField class.

        Args:
            page (PdfPageBase): The PDF page.
            name (str): The name of the field.
        """
        ptrPage: c_void_p = page.Ptr
        GetDllLibPdf().PdfRadioButtonListField_CreatePdfRadioButtonListFieldPN.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfRadioButtonListField_CreatePdfRadioButtonListFieldPN.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRadioButtonListField_CreatePdfRadioButtonListFieldPN,ptrPage, name)
        super(PdfRadioButtonListField, self).__init__(intPtr)

    @property
    def SelectedIndex(self) -> int:
        """
        Gets or sets the first selected item in the list.

        Returns:
            int: The index of the selected item.
        """
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedIndex.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedIndex.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfRadioButtonListField_get_SelectedIndex,self.Ptr)
        return ret

    @SelectedIndex.setter
    def SelectedIndex(self, value: int):
        """
        Sets the index of the selected item in the list.

        Args:
            value (int): The index of the selected item.
        """
        GetDllLibPdf().PdfRadioButtonListField_set_SelectedIndex.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfRadioButtonListField_set_SelectedIndex,self.Ptr, value)

    @property
    def SelectedValue(self) -> str:
        """
        Gets or sets the value of the first selected item in the list.

        Returns:
            str: The selected value of the list field.
        """
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedValue.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedValue.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfRadioButtonListField_get_SelectedValue,self.Ptr))
        return ret

    @SelectedValue.setter
    def SelectedValue(self, value: str):
        """
        Sets the value of the first selected item in the list.

        Args:
            value (str): The selected value of the list field.
        """
        GetDllLibPdf().PdfRadioButtonListField_set_SelectedValue.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfRadioButtonListField_set_SelectedValue,self.Ptr, value)

    @property
    def SelectedItem(self) -> 'PdfRadioButtonListItem':
        """
        Gets the first selected item in the list.

        Returns:
            PdfRadioButtonListItem: The selected item of the field.
        """
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedItem.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonListField_get_SelectedItem.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRadioButtonListField_get_SelectedItem,self.Ptr)
        ret = None if intPtr == None else PdfRadioButtonListItem(intPtr)
        return ret

    @property
    def Items(self) -> 'PdfRadioButtonItemCollection':
        """
        Gets the items of the radio button field.

        Returns:
            PdfRadioButtonItemCollection: The radio button field item collection.
        """
        GetDllLibPdf().PdfRadioButtonListField_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonListField_get_Items.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRadioButtonListField_get_Items,self.Ptr)
        ret = None if intPtr == None else PdfRadioButtonItemCollection(intPtr)
        return ret