from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSectionPageNumberField(PdfMultipleNumberValueField):
    """
    Represents automatic field to display page number within a section.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfSectionPageNumberField class.
        """
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberField.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberField)
        super(PdfSectionPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfSectionPageNumberField class with the specified font.

        :param font: The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldF,ptrFont)
        super(PdfSectionPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfSectionPageNumberField class with the specified font and brush.

        :param font: The font to use for the field.
        :param brush: The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFB.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFB,ptrFont, ptrBrush)
        super(PdfSectionPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfSectionPageNumberField class with the specified font and bounds.

        :param font: The font to use for the field.
        :param bounds: The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFBs.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionPageNumberField_CreatePdfSectionPageNumberFieldFBs,ptrFont, ptrBounds)
        super(PdfSectionPageNumberField, self).__init__(intPtr)