from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignatureAppearance(IPdfSignatureAppearance):
    """
    Provide a custom signature appearance implementation.
    """

    @dispatch
    def __init__(self, signature:PdfSignature):
        intPtrsignature:c_void_p = signature.Ptr

        GetDllLibPdf().PdfSignatureAppearance_CreatePdfSignatureAppearanceS.argtypes=[c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_CreatePdfSignatureAppearanceS.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSignatureAppearance_CreatePdfSignatureAppearanceS,intPtrsignature)
        super(PdfSignatureAppearance, self).__init__(intPtr)
    @property
    def NameLabel(self) -> str:
        """
        The label of the name of the person or authority signing the document.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_NameLabel.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_NameLabel.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_NameLabel,self.Ptr))
        return ret

    @NameLabel.setter
    def NameLabel(self, value: str):
        GetDllLibPdf().PdfSignatureAppearance_set_NameLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_NameLabel,self.Ptr, value)

    @property
    def ReasonLabel(self) -> str:
        """
        The label of the signature's reason.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_ReasonLabel.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_ReasonLabel.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_ReasonLabel,self.Ptr))
        return ret

    @ReasonLabel.setter
    def ReasonLabel(self, value: str):
        GetDllLibPdf().PdfSignatureAppearance_set_ReasonLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_ReasonLabel,self.Ptr, value)

    @property
    def LocationLabel(self) -> str:
        """
        The label of the signature's location.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_LocationLabel.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_LocationLabel.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_LocationLabel,self.Ptr))
        return ret

    @LocationLabel.setter
    def LocationLabel(self, value: str):
        GetDllLibPdf().PdfSignatureAppearance_set_LocationLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_LocationLabel,self.Ptr, value)

    @property
    def ContactInfoLabel(self) -> str:
        """
        The label of the signature's contactInfo.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_ContactInfoLabel.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_ContactInfoLabel.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_ContactInfoLabel,self.Ptr))
        return ret

    @ContactInfoLabel.setter
    def ContactInfoLabel(self, value: str):
        GetDllLibPdf().PdfSignatureAppearance_set_ContactInfoLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_ContactInfoLabel,self.Ptr, value)

    @property
    def DateLabel(self) -> str:
        """
        The label of the signature's date.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_DateLabel.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_DateLabel.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_DateLabel,self.Ptr))
        return ret

    @DateLabel.setter
    def DateLabel(self, value: str):
        GetDllLibPdf().PdfSignatureAppearance_set_DateLabel.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_DateLabel,self.Ptr, value)

    @property
    def SignatureImage(self) -> 'PdfImage':
        """
        The signature image.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_SignatureImage.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_SignatureImage.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_SignatureImage,self.Ptr)
        ret = None if intPtr == None else PdfImage(intPtr)
        return ret

    @SignatureImage.setter
    def SignatureImage(self, value: 'PdfImage'):
        GetDllLibPdf().PdfSignatureAppearance_set_SignatureImage.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_SignatureImage,self.Ptr, value.Ptr)

    @property
    def GraphicMode(self) -> 'GraphicMode':
        """
        The graphic render/display mode.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_GraphicMode.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_GraphicMode.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_GraphicMode,self.Ptr)
        objwrapped = GraphicMode(ret)
        return objwrapped

    @GraphicMode.setter
    def GraphicMode(self, value: 'GraphicMode'):
        GetDllLibPdf().PdfSignatureAppearance_set_GraphicMode.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_GraphicMode,self.Ptr, value.value)

    @property
    def SignImageLayout(self) -> 'SignImageLayout':
        """
        The sign image layout.
        """
        GetDllLibPdf().PdfSignatureAppearance_get_SignImageLayout.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureAppearance_get_SignImageLayout.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSignatureAppearance_get_SignImageLayout,self.Ptr)
        objwrapped = SignImageLayout(ret)
        return objwrapped

    @SignImageLayout.setter
    def SignImageLayout(self, value: 'SignImageLayout'):
        GetDllLibPdf().PdfSignatureAppearance_set_SignImageLayout.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_set_SignImageLayout,self.Ptr, value.value)

    def Generate(self, g: 'PdfCanvas'):
        """
        Generate custom signature appearance by a graphics context.
        :param g: A graphics context of signature appearance.
        """
        intPtrg: c_void_p = g.Ptr

        GetDllLibPdf().PdfSignatureAppearance_Generate.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSignatureAppearance_Generate,self.Ptr, intPtrg)