from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSoundAnnotationWidget(PdfStyledAnnotationWidget):
    """
    Represents the loaded sound annotation class.
    """

    @property
    def Sound(self) -> 'PdfSound':
        """
        Gets or sets the sound of the annotation.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_get_Sound.argtypes = [c_void_p]
        GetDllLibPdf().PdfSoundAnnotationWidget_get_Sound.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_get_Sound,self.Ptr)
        ret = None if intPtr == None else PdfSound(intPtr)
        return ret

    @Sound.setter
    def Sound(self, value: 'PdfSound'):
        """
        Sets the sound of the annotation.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_set_Sound.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_set_Sound,self.Ptr, value.Ptr)

    @property
    def FileName(self) -> str:
        """
        Gets the filename of the annotation.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_get_FileName.argtypes = [c_void_p]
        GetDllLibPdf().PdfSoundAnnotationWidget_get_FileName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_get_FileName,self.Ptr))
        return ret

    @property
    def Icon(self) -> 'PdfSoundIcon':
        """
        Gets or sets the icon of the annotation.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_get_Icon.argtypes = [c_void_p]
        GetDllLibPdf().PdfSoundAnnotationWidget_get_Icon.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_get_Icon,self.Ptr)
        objwrapped = PdfSoundIcon(ret)
        return objwrapped

    @Icon.setter
    def Icon(self, value: 'PdfSoundIcon'):
        """
        Sets the icon of the annotation.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_set_Icon.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_set_Icon,self.Ptr, value.value)

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfSoundAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfSoundAnnotationWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSoundAnnotationWidget_ObjectID,self.Ptr)
        return ret