from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStringLayouter(SpireObject):
    """
    Class for laying out text.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfStringLayouter class.
        """
        GetDllLibPdf().PdfStringLayouter_CreatePdfStringLayouter.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStringLayouter_CreatePdfStringLayouter)
        super(PdfStringLayouter, self).__init__(intPtr)

    def Layout(self, text: str, font: 'PdfFontBase', strFormat: 'PdfStringFormat', size: 'SizeF') -> 'PdfStringLayoutResult':
        """
        Layouts the text.
        
        Args:
            text: The string text.
            font: The font for the text.
            strFormat: The string format.
            size: The bounds of the text.
        
        Returns:
            The layout result.
        """
        intPtrfont: c_void_p = font.Ptr
        intPtrformat: c_void_p = strFormat.Ptr
        intPtrsize: c_void_p = size.Ptr

        GetDllLibPdf().PdfStringLayouter_Layout.argtypes = [c_void_p, c_wchar_p, c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfStringLayouter_Layout.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStringLayouter_Layout,self.Ptr, text, intPtrfont, intPtrformat, intPtrsize)
        ret = None if intPtr == None else PdfStringLayoutResult(intPtr)
        return ret