from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStructureAttributes(SpireObject):
    """
    The attribute information is held in one or more attribute objects
    associated with the structure element.
    """

    @property
    def Owner(self) -> 'PdfAttributeOwner':
        """
        Get the owner of the attribute.
        """
        GetDllLibPdf().PdfStructureAttributes_get_Owner.argtypes = [c_void_p]
        GetDllLibPdf().PdfStructureAttributes_get_Owner.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStructureAttributes_get_Owner,self.Ptr)
        ret = None if intPtr == None else PdfAttributeOwner(intPtr)
        return ret

    def GetNameValue(self, key: str) -> str:
        """
        Get the attribute value.

        Args:
            key: The attribute key.

        Returns:
            The attribute value.
        """
        GetDllLibPdf().PdfStructureAttributes_GetNameValue.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfStructureAttributes_GetNameValue.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStructureAttributes_GetNameValue,self.Ptr, key))
        return ret

    def SetNameValue(self, key: str, value: str):
        """
        Set the attribute value.

        Args:
            key: The attribute key.
            value: The attribute value.
        """
        GetDllLibPdf().PdfStructureAttributes_SetNameValue.argtypes = [c_void_p, c_wchar_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStructureAttributes_SetNameValue,self.Ptr, key, value)

    def GetNameArrayValue(self, key: str) -> List[str]:
        """
        Get the attribute value.

        Args:
            key: The attribute key.

        Returns:
            The attribute value.
        """
        GetDllLibPdf().PdfStructureAttributes_GetNameArrayValue.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfStructureAttributes_GetNameArrayValue.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfStructureAttributes_GetNameArrayValue,self.Ptr, key)
        ret = GetStrVectorFromArray(intPtrArray, c_void_p)
        return ret

    def SetNameArrayValue(self, key: str, value: List[str]):
        """
        Set the attribute value.

        Args:
            key: The attribute key.
            value: The attribute value.
        """
        countvalue = len(value)
        ArrayTypevalue = c_wchar_p * countvalue
        arrayvalue = ArrayTypevalue()
        for i in range(0, countvalue):
            arrayvalue[i] = value[i]

        GetDllLibPdf().PdfStructureAttributes_SetNameArrayValue.argtypes = [c_void_p, c_wchar_p, ArrayTypevalue]
        CallCFunction(GetDllLibPdf().PdfStructureAttributes_SetNameArrayValue,self.Ptr, key, arrayvalue)