from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTextBoxFieldWidget (  PdfStyledFieldWidget, IPdfTextBoxField) :
    """
    Represents the text box field of an existing PDF document`s form.
    """
    @property

    def ForeColor(self)->'PdfRGBColor':
        """
        Gets or Set the fore color of the field.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_ForeColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_ForeColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_ForeColor,self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @ForeColor.setter
    def ForeColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_ForeColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_ForeColor,self.Ptr, value.Ptr)

    @property

    def TextAlignment(self)->'PdfTextAlignment':
        """
        Get or Set the text alignment in a text box.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_TextAlignment.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_TextAlignment.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_TextAlignment,self.Ptr)
        objwraped = PdfTextAlignment(ret)
        return objwraped

    @TextAlignment.setter
    def TextAlignment(self, value:'PdfTextAlignment'):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_TextAlignment.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_TextAlignment,self.Ptr, value.value)

    @property

    def HighlightMode(self)->'PdfHighlightMode':
        """
        Get or Set the HighLightMode of the Field.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_HighlightMode.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_HighlightMode.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_HighlightMode,self.Ptr)
        objwraped = PdfHighlightMode(ret)
        return objwraped

    @HighlightMode.setter
    def HighlightMode(self, value:'PdfHighlightMode'):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_HighlightMode.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_HighlightMode,self.Ptr, value.value)

    @property

    def Text(self)->str:
        """
        Gets or Set value of the text box field.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Text.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Text.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_Text,self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_Text.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_Text,self.Ptr, value)

    @property

    def DefaultValue(self)->str:
        """
        Gets or set the default value of the field.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_DefaultValue.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_DefaultValue.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_DefaultValue,self.Ptr))
        return ret


    @DefaultValue.setter
    def DefaultValue(self, value:str):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_DefaultValue.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_DefaultValue,self.Ptr, value)

    @property
    def SpellCheck(self)->bool:
        """
        Gets or sets a value indicating whether to check spelling.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_SpellCheck.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_SpellCheck.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_SpellCheck,self.Ptr)
        return ret

    @SpellCheck.setter
    def SpellCheck(self, value:bool):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_SpellCheck.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_SpellCheck,self.Ptr, value)

    @property
    def InsertSpaces(self)->bool:
        """
        Meaningful only if the MaxLength property is set and the Multiline, Password properties are false.
            If set, the field is automatically divided into as many equally spaced positions, or combs, 
            as the value of MaxLength, and the text is laid out into those combs.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_InsertSpaces.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_InsertSpaces.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_InsertSpaces,self.Ptr)
        return ret

    @InsertSpaces.setter
    def InsertSpaces(self, value:bool):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_InsertSpaces.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_InsertSpaces,self.Ptr, value)

    @property
    def Multiline(self)->bool:
        """
        Gets or sets a value indicating whether this  is multiline.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Multiline.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Multiline.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_Multiline,self.Ptr)
        return ret

    @Multiline.setter
    def Multiline(self, value:bool):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_Multiline.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_Multiline,self.Ptr, value)

    @property
    def Password(self)->bool:
        """
        Gets or sets a value indicating whether this  is password field.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Password.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Password.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_Password,self.Ptr)
        return ret

    @Password.setter
    def Password(self, value:bool):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_Password.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_Password,self.Ptr, value)

    @property
    def Scrollable(self)->bool:
        """
        Gets or sets a value indicating whether this  is scrollable.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Scrollable.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_Scrollable.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_Scrollable,self.Ptr)
        return ret

    @Scrollable.setter
    def Scrollable(self, value:bool):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_Scrollable.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_Scrollable,self.Ptr, value)

    @property
    def MaxLength(self)->int:
        """
        Gets or sets the maximum length of the field, in characters.
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_MaxLength.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_MaxLength.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_MaxLength,self.Ptr)
        return ret

    @MaxLength.setter
    def MaxLength(self, value:int):
        GetDllLibPdf().PdfTextBoxFieldWidget_set_MaxLength.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_set_MaxLength,self.Ptr, value)

    @property

    def WidgetItems(self)->'PdfTextBoxWidgetItemCollection':
        """
        Gets the collection of text box field items. 
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_get_WidgetItems.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_get_WidgetItems.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_get_WidgetItems,self.Ptr)
        ret = None if intPtr==None else PdfTextBoxWidgetItemCollection(intPtr)
        return ret


    def ObjectID(self)->int:
        """
        Form field identifier
        """
        GetDllLibPdf().PdfTextBoxFieldWidget_ObjectID.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextBoxFieldWidget_ObjectID.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfTextBoxFieldWidget_ObjectID,self.Ptr)
        return ret

